# catxlsx package: 
* catxlsx: Reading xlsx on server same cat command
# For development
## requirement
- virtualenv
- python 3+
## setup
  clone project and run `python setup.py develop`
  test by run it `catxlsx -h`


